;; Generated package description from fedi.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "fedi" "0.4.0.20260509.80113" "Helper functions for fediverse clients" '((emacs "28.1") (markdown-mode "2.5")) :commit "91f28ee199a499b8d6e1b9c7a0f1c15f8a382198" :authors '(("Marty Hiatt" . "martianh@disroot.org")) :maintainer '("Marty Hiatt" . "martianh@disroot.org") :url "https://codeberg.org/martianh/fedi.el")
